# stream-sea-client-python

## Stream-sea-client-python developer documentation
- Developer tooling can be installed with `pip install -r dev-requirements.txt`
- The project uses `pycodestyle` as a linter. To lint the project, run `pycodestyle ./`
